@@ -311,37 +311,61 @@ class AddWindow(gtk.Dialog):
         self.show_all()
 
 
+class AdvancedWindow(gtk.Dialog):
+
+
+    def __init__(self, parent):
+        gtk.Dialog.__init__(self, None, parent,
+            gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+            (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
+             gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+        self.set_title("Advanced feed settings")
+        self.days_editor = hildon.NumberEditor(1, 365)
+        self.ignore_print_version_button = gtk.CheckButton()
+        self.include_entry = gtk.Entry()
+        self.exclude_entry = gtk.Entry()
+        table = gtk.Table(rows = 4, columns = 2)
+        texts = ["Days to keep", "Ignore print version", "Include pattern", "Exclude pattern" ]
+        for i in range(0, len(texts)):
+            label = gtk.Label(texts[i])
+            label.set_alignment(1, 1)
+            table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
+        table.attach(self.days_editor, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
+        table.attach(self.ignore_print_version_button, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
+        table.attach(self.include_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        table.attach(self.exclude_entry, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
+        self.vbox.add(table)
+        self.show_all()
+
+
 class EditWindow(gtk.Dialog):
 
 
-    def __init__(self, parent, feed_config = None):
+    def __init__(self, parent, feed_config):
         gtk.Dialog.__init__(self, None, parent,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
             (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
              gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
         self.set_title("Edit feed")
         self.feed_config = feed_config
+        self.days_to_keep = feed_config.days_to_keep 
+        self.include = feed_config.include
+        self.exclude = feed_config.exclude
+        self.ignore_print_version = feed_config.ignore_print_version
         self.url_entry = gtk.Entry()
         self.url_entry.set_width_chars(32)
         self.url_entry.set_text(feed_config.url)
         self.name_entry = gtk.Entry()
         self.name_entry.set_text(feed_config.name)
         self.mode_combo = gtk.combo_box_new_text()
-        self.mode_combo.append_text("Ommit")
+        self.mode_combo.append_text("Do nothing")
         self.mode_combo.append_text("Cache")
         self.mode_combo.append_text("Inline")
         self.mode_combo.set_active(feed_config.mode)
-        self.days_editor = hildon.NumberEditor(1, 365)
-        self.days_editor.set_value(feed_config.days_to_keep)
-        self.ignore_print_version_button = gtk.CheckButton()
-        self.ignore_print_version_button.set_active(feed_config.ignore_print_version)
-        self.include_entry = gtk.Entry()
-        self.include_entry.set_text(feed_config.include)
-        self.exclude_entry = gtk.Entry()
-        self.exclude_entry.set_text(feed_config.exclude)
-        table = gtk.Table(rows = 7, columns = 2)
-        texts = ["Url", "Name", "Source", "Days to keep", "Ignore print version",
-            "Include pattern", "Exclude pattern" ]
+        self.advanced_button = gtk.Button("Advanced")
+        self.advanced_button.connect("clicked", self.advanced_clicked)
+        table = gtk.Table(rows = 4, columns = 2)
+        texts = ["Url", "Name", "Content"]
         for i in range(0, len(texts)):
             label = gtk.Label(texts[i])
             label.set_alignment(1, 1)
@@ -349,10 +373,9 @@ class EditWindow(gtk.Dialog):
         table.attach(self.url_entry, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
         table.attach(self.name_entry, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
         table.attach(self.mode_combo, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
-        table.attach(self.days_editor, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
-        table.attach(self.ignore_print_version_button, 1, 2, 4, 5, xpadding = 3, ypadding = 3)
-        table.attach(self.include_entry, 1, 2, 5, 6, xpadding = 3, ypadding = 3)
-        table.attach(self.exclude_entry, 1, 2, 6, 7, xpadding = 3, ypadding = 3)
+        hbox = gtk.HBox()
+        hbox.pack_end(self.advanced_button, expand = False)
+        table.attach(hbox, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
         self.vbox.add(table)
         self.show_all()
 
@@ -360,10 +383,25 @@ class EditWindow(gtk.Dialog):
         self.feed_config.url = self.url_entry.get_text()
         self.feed_config.name = self.name_entry.get_text()
         self.feed_config.mode = self.mode_combo.get_active()
-        self.feed_config.days_to_keep = self.days_editor.get_value()
-        self.feed_config.include = self.include_entry.get_text()
-        self.feed_config.exclude = self.exclude_entry.get_text()
-        self.ignore_print_version = self.ignore_print_version_button.get_active()
+        self.feed_config.days_to_keep = self.days_to_keep
+        self.feed_config.include = self.include
+        self.feed_config.exclude = self.exclude
+        self.feed_config.ignore_print_version = self.ignore_print_version
+
+
+    def advanced_clicked(self, source):
+        adv_window = AdvancedWindow(self)
+        adv_window.days_editor.set_value(self.days_to_keep)
+        adv_window.ignore_print_version_button.set_active(self.ignore_print_version)
+        adv_window.include_entry.set_text(self.include)
+        adv_window.exclude_entry.set_text(self.exclude)
+        result = adv_window.run()
+        adv_window.hide()
+        if result == gtk.RESPONSE_ACCEPT:
+            self.days_to_keep = adv_window.days_editor.get_value()
+            self.ignore_print_version = adv_window.ignore_print_version_button.get_active()
+            self.include = adv_window.include_entry.get_text()
+            self.exclude = adv_window.exclude_entry.get_text()
 
 
 class Program(hildon.Program):
@@ -389,10 +427,12 @@ class Program(hildon.Program):
         self.__toolbar.set_style(gtk.TOOLBAR_ICONS)
         self.append_action(menu, self.__toolbar, "Open", gtk.STOCK_OPEN, self.open)
         self.append_action(menu, self.__toolbar, "Refresh all", gtk.STOCK_REFRESH, self.refresh)
-        self.append_action(menu, self.__toolbar, "Add", gtk.STOCK_ADD, self.add)
-        self.append_action(menu, self.__toolbar, "Edit", None, self.edit)
+        self.append_action(menu, self.__toolbar, "Add...", gtk.STOCK_ADD, self.add)
+        self.append_action(menu, self.__toolbar, "Edit...", None, self.edit)
         self.append_action(menu, self.__toolbar, "Refresh", None, self.refresh_current)
         self.append_action(menu, self.__toolbar, "Remove", None, self.remove)
+        menu.append(gtk.SeparatorMenuItem())
+        self.append_action(menu, self.__toolbar, "About...", None, self.about)
         self.append_action(menu, self.__toolbar, "Close", None, self.stop)
         self.__progress_label = gtk.Label()
         self.__progress_label.set_alignment(0, 0.5)
@@ -625,3 +665,13 @@ class Program(hildon.Program):
                 if os.path.exists(icon_filepath):
                     os.remove(icon_filepath)
             self.__model.delete(feed_config.id)
+
+
+    def about(self, source):
+        dialog = gtk.AboutDialog()
+        dialog.set_name("FeedCircuit")
+        dialog.set_version("0.5.1")
+        dialog.set_website("http://feedcircuit.garage.maemo.org")
+        dialog.set_authors(["George Kibardin"])
+        dialog.run()
+        dialog.hide()
